@@ -1,6 +1,6 @@
 use cssparser::{BasicParseError, Parser, Token};
 
-use drawing_ctx::DrawingCtx;
+use drawing_ctx::ViewParams;
 use error::*;
 use length::{Length, LengthDir, LengthUnit, POINTS_PER_INCH};
 use parsers::{Parse, ParseError};
@@ -67,16 +67,19 @@ impl FontSizeSpec {
         FontSizeSpec::Value(new_size)
     }
 
-    pub fn normalize(&self, values: &ComputedValues, draw_ctx: &DrawingCtx) -> f64 {
-        self.value().normalize(values, draw_ctx)
+    pub fn normalize(&self, values: &ComputedValues, params: &ViewParams) -> f64 {
+        self.value().normalize(values, params)
     }
 }
 
 impl Parse for FontSizeSpec {
     type Data = ();
-    type Err = AttributeError;
+    type Err = ValueErrorKind;
 
-    fn parse(parser: &mut Parser, _: Self::Data) -> Result<FontSizeSpec, ::error::AttributeError> {
+    fn parse(
+        parser: &mut Parser<'_, '_>,
+        _: Self::Data,
+    ) -> Result<FontSizeSpec, ::error::ValueErrorKind> {
         let parser_state = parser.state();
 
         Length::parse(parser, LengthDir::Both)
@@ -86,7 +89,7 @@ impl Parse for FontSizeSpec {
 
                 {
                     let token = parser.next().map_err(|_| {
-                        ::error::AttributeError::Parse(::parsers::ParseError::new("expected token"))
+                        ::error::ValueErrorKind::Parse(::parsers::ParseError::new("expected token"))
                     })?;
 
                     if let Token::Ident(ref cow) = token {
@@ -132,12 +135,12 @@ pub enum FontWeightSpec {
 
 impl Parse for FontWeightSpec {
     type Data = ();
-    type Err = AttributeError;
+    type Err = ValueErrorKind;
 
     fn parse(
-        parser: &mut Parser,
+        parser: &mut Parser<'_, '_>,
         _: Self::Data,
-    ) -> Result<FontWeightSpec, ::error::AttributeError> {
+    ) -> Result<FontWeightSpec, ::error::ValueErrorKind> {
         if let Ok(r) = parser.try(|p| {
             p.expect_ident()
                 .map_err(|_| ())
@@ -169,7 +172,7 @@ impl Parse for FontWeightSpec {
             }) {
             Ok(r)
         } else {
-            Err(AttributeError::Parse(ParseError::new(
+            Err(ValueErrorKind::Parse(ParseError::new(
                 "invalid font-weight specification",
             )))
         }
@@ -202,19 +205,19 @@ impl LetterSpacingSpec {
         LetterSpacingSpec::Value(spacing)
     }
 
-    pub fn normalize(&self, values: &ComputedValues, draw_ctx: &DrawingCtx) -> f64 {
-        self.value().normalize(values, draw_ctx)
+    pub fn normalize(&self, values: &ComputedValues, params: &ViewParams) -> f64 {
+        self.value().normalize(values, params)
     }
 }
 
 impl Parse for LetterSpacingSpec {
     type Data = ();
-    type Err = AttributeError;
+    type Err = ValueErrorKind;
 
     fn parse(
-        parser: &mut Parser,
+        parser: &mut Parser<'_, '_>,
         _: Self::Data,
-    ) -> Result<LetterSpacingSpec, ::error::AttributeError> {
+    ) -> Result<LetterSpacingSpec, ::error::ValueErrorKind> {
         let parser_state = parser.state();
 
         Length::parse(parser, LengthDir::Horizontal)
@@ -224,7 +227,7 @@ impl Parse for LetterSpacingSpec {
 
                 {
                     let token = parser.next().map_err(|_| {
-                        ::error::AttributeError::Parse(::parsers::ParseError::new("expected token"))
+                        ::error::ValueErrorKind::Parse(::parsers::ParseError::new("expected token"))
                     })?;
 
                     if let Token::Ident(ref cow) = token {
@@ -248,16 +251,19 @@ pub struct SingleFontFamily(pub String);
 
 impl Parse for SingleFontFamily {
     type Data = ();
-    type Err = AttributeError;
+    type Err = ValueErrorKind;
 
-    fn parse(parser: &mut Parser, _: Self::Data) -> Result<SingleFontFamily, AttributeError> {
+    fn parse(
+        parser: &mut Parser<'_, '_>,
+        _: Self::Data,
+    ) -> Result<SingleFontFamily, ValueErrorKind> {
         parse_single_font_family(parser)
-            .map_err(|_| AttributeError::from(ParseError::new("expected font family")))
+            .map_err(|_| ValueErrorKind::from(ParseError::new("expected font family")))
     }
 }
 
 fn parse_single_font_family<'i>(
-    parser: &'i mut Parser,
+    parser: &'i mut Parser<'_, '_>,
 ) -> Result<SingleFontFamily, BasicParseError<'i>> {
     if let Ok(cow) = parser.try(|p| p.expect_string_cloned()) {
         return Ok(SingleFontFamily((*cow).to_owned()));
