@@ -4,7 +4,7 @@ use glib_sys;
 use std::cell::Cell;
 use std::rc::Rc;
 
-use node::{box_node, Node, RsvgNode};
+use node::{box_node, Node, NodeType, RsvgNode};
 use state::ComputedValues;
 
 pub enum RsvgTree {}
@@ -29,6 +29,10 @@ impl Tree {
             self.root.cascade(&values);
         }
     }
+
+    fn root_is_svg(&self) -> bool {
+        self.root.get_type() == NodeType::Svg
+    }
 }
 
 #[no_mangle]
@@ -76,3 +80,11 @@ pub extern "C" fn rsvg_tree_is_root(
 
     Rc::ptr_eq(&tree.root, node).to_glib()
 }
+
+#[no_mangle]
+pub extern "C" fn rsvg_tree_root_is_svg(tree: *const RsvgTree) -> glib_sys::gboolean {
+    assert!(!tree.is_null());
+    let tree = unsafe { &*(tree as *const Tree) };
+
+    tree.root_is_svg().to_glib()
+}
